@@ -39,8 +39,16 @@ SENTRY_KEY = %(default_key)r
 # Set this to false to require authentication
 SENTRY_PUBLIC = True
 
+# You should configure the absolute URI to Sentry. It will attempt to guess it if you don't
+# but proxies may interfere with this.
+# SENTRY_URL_PREFIX = 'http://sentry.example.com'  # No trailing slash!
+
 SENTRY_WEB_HOST = '0.0.0.0'
 SENTRY_WEB_PORT = 9000
+SENTRY_WEB_OPTIONS = {
+    'workers': 3,  # the number of gunicorn workers
+}
+
 """
 
 
